import 'package:flutter/material.dart';
import 'package:view_helper/src/Helpers/Views/CircleIconView.dart';

class ImagesView extends StatelessWidget {
  final List<String> images;
  final Function addImage;
  final Function removeImage;
  final bool isLoading;

  ImagesView({
    this.images,
    this.addImage,
    this.removeImage,
    this.isLoading
  });

  Widget _buildPicture(int index) {
    Widget icon;

    Key key;

    if (images.length >= index) {
      icon = isLoading ? CircularProgressIndicator() : Icon(Icons.add_a_photo);

      key = Key("camera_plus");
    } else {
      icon = Icon(Icons.photo_camera);

      key = Key("camera");
    }

    Widget widget;

    if (images.length - 1 >= index) {
      widget = GestureDetector(
          child: CircleAvatar(backgroundImage: NetworkImage(images[index])),
          onTap: () {
            removeImage(images[index]);
          }
      );
    } else {
      widget = CircleIconView(
        key: key,
        icon: icon,
        onPressed: key == Key("camera_plus") ? addImage : null,
        radius: 60.0,
      );
    }

    return Padding(
      padding: const EdgeInsets.all(16.0),
      child: widget,
    );
  }

  Widget _buildPictures(BuildContext context) {
    return GridView.builder(
        physics: NeverScrollableScrollPhysics(),
        shrinkWrap: true,
        gridDelegate:
        SliverGridDelegateWithFixedCrossAxisCount(crossAxisCount: 3),
        itemCount: 6,
        itemBuilder: (BuildContext context, int index) {
          return _buildPicture(index);
        });
  }

  @override
  Widget build(BuildContext context) {
    return _buildPictures(context);
  }

}
